import React from "react";
import { StreamInfo } from "./api";

type StreamSelectCallback = (selected: string | null) => void;

interface MenuProps {
  items: StreamInfo[];
  selectedItem: string | null;
  selectCallback: StreamSelectCallback;
}

export function Menu({ items, selectedItem, selectCallback }: MenuProps) {
  const title = document.title;
  const menuitems = () => {
    return (
      <>
        {items.map((value) => {
          const key = `${value.streamKey}_${value.viewCount}`
          if (selectedItem == value.streamKey) {
            return (
                <li key={key} className="menu-item menu-selected">
                  <a className="menu-link">
                    {value.streamKey}
                  </a>
                  <p className="menu-viewcount">{value.viewCount}</p>
                </li>
            );
          } else {
            return (
                <li
                  key={value.streamKey}
                  onClick={() => {
                    selectCallback(value.streamKey);
                  }}
                  className="menu-item"
                >
                  <a className="menu-link">
                    {value.streamKey}
                  </a>
                  <p className="menu-viewcount">{value.viewCount}</p>
                </li>
            );
          }
        })}
      </>
    );
  };
  return (
    <div id="menu">
      <aside>
        <a
          className="menu-heading"
          onClick={() => {
            selectCallback(null);
          }}
          href="#">
          {title}
        </a>
        <ul className="menu-list">{menuitems()}</ul>
      </aside>
    </div>
  );
}
